@@ -1895,6 +1895,114 @@ class NcmClient:
         result = self.__return_handler(ncm.status_code, ncm.text, call_type)
         return result
 
+    def set_router_name(self, router_id: int, new_router_name: str):
+        """
+        This method sets the local admin password for a router.
+        :param router_id: ID of router to update
+        :param new_router_name: Name/System ID to set
+        :return:
+        """
+        call_type = 'Router Name'
+
+        response = self.session.get(
+            '{0}/configuration_managers/?router.id={1}&fields=id'.format(
+                self.base_url,
+                str(router_id)))  # Get Configuration Managers ID
+        response = json.loads(response.content.decode(
+            "utf-8"))  # Decode the response and make it a dictionary
+        config_man_id = response['data'][0][
+            'id']  # get the Configuration Managers ID from response
+
+        payload = {
+            "configuration": [
+                {
+                    "system": {
+                        "system_id": new_router_name
+                    }
+                },
+                []
+            ]
+        }
+
+        ncm = self.session.patch(
+            '{0}/configuration_managers/{1}/'.format(self.base_url,
+                                                     str(config_man_id)),
+            data=json.dumps(payload))  # Patch indie config with new values
+        result = self.__return_handler(ncm.status_code, ncm.text, call_type)
+        return result
+
+    def set_router_description(self, router_id: int, new_router_description: str):
+        """
+        This method sets the local admin password for a router.
+        :param router_id: ID of router to update
+        :param new_router_description: Description string to set
+        :return:
+        """
+        call_type = 'Description'
+
+        response = self.session.get(
+            '{0}/configuration_managers/?router.id={1}&fields=id'.format(
+                self.base_url,
+                str(router_id)))  # Get Configuration Managers ID
+        response = json.loads(response.content.decode(
+            "utf-8"))  # Decode the response and make it a dictionary
+        config_man_id = response['data'][0][
+            'id']  # get the Configuration Managers ID from response
+
+        payload = {
+            "configuration": [
+                {
+                    "system": {
+                        "desc": new_router_description
+                    }
+                },
+                []
+            ]
+        }
+
+        ncm = self.session.patch(
+            '{0}/configuration_managers/{1}/'.format(self.base_url,
+                                                     str(config_man_id)),
+            data=json.dumps(payload))  # Patch indie config with new values
+        result = self.__return_handler(ncm.status_code, ncm.text, call_type)
+        return result
+
+    def set_router_asset_id(self, router_id: int, new_router_asset_id: str):
+        """
+        This method sets the local admin password for a router.
+        :param router_id: ID of router to update
+        :param new_router_asset_id: Asset ID string to set
+        :return:
+        """
+        call_type = 'Asset ID'
+
+        response = self.session.get(
+            '{0}/configuration_managers/?router.id={1}&fields=id'.format(
+                self.base_url,
+                str(router_id)))  # Get Configuration Managers ID
+        response = json.loads(response.content.decode(
+            "utf-8"))  # Decode the response and make it a dictionary
+        config_man_id = response['data'][0][
+            'id']  # get the Configuration Managers ID from response
+
+        payload = {
+            "configuration": [
+                {
+                    "system": {
+                        "asset_id": new_router_asset_id
+                    }
+                },
+                []
+            ]
+        }
+
+        ncm = self.session.patch(
+            '{0}/configuration_managers/{1}/'.format(self.base_url,
+                                                     str(config_man_id)),
+            data=json.dumps(payload))  # Patch indie config with new values
+        result = self.__return_handler(ncm.status_code, ncm.text, call_type)
+        return result
+
     def set_ethernet_wan_ip(self, router_id: int, new_wan_ip: str,
                             new_netmask: str = None, new_gateway: str = None):
         """
